==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/MqttBridgeRemoteBrokerConnectionSpecArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.MqttBridgeRemoteBrokerConnectionSpecArgs.builder
import com.pulumi.azurenative.iotoperationsmq.kotlin.enums.MqttBridgeRemoteBrokerProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * MqttBridge RemoteBrokerConnectionSpec details
 * @property authentication The remote broker authentication methods. NOTE - Enum only one method is allowed to be passed.
 * @property endpoint The endpoint of remote broker to connect to.
 * @property protocol Protocol for remote connection.
 * @property tls TLS details for Remote broker Connection.
 */
public data class MqttBridgeRemoteBrokerConnectionSpecArgs(
    public val authentication: Output<MqttBridgeRemoteBrokerAuthenticationMethodsArgs>,
    public val endpoint: Output<String>,
    public val protocol: Output<Either<String, MqttBridgeRemoteBrokerProtocol>>? = null,
    public val tls: Output<MqttBridgeRemoteBrokerConnectionTlsArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.MqttBridgeRemoteBrokerConnectionSpecArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsmq.inputs.MqttBridgeRemoteBrokerConnectionSpecArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.MqttBridgeRemoteBrokerConnectionSpecArgs.builder()
            .authentication(authentication.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .endpoint(endpoint.applyValue({ args0 -> args0 }))
            .protocol(
                protocol?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .tls(tls.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [MqttBridgeRemoteBrokerConnectionSpecArgs].
 */
@PulumiTagMarker
public class MqttBridgeRemoteBrokerConnectionSpecArgsBuilder internal constructor() {
    private var authentication: Output<MqttBridgeRemoteBrokerAuthenticationMethodsArgs>? = null

    private var endpoint: Output<String>? = null

    private var protocol: Output<Either<String, MqttBridgeRemoteBrokerProtocol>>? = null

    private var tls: Output<MqttBridgeRemoteBrokerConnectionTlsArgs>? = null

    /**
     * @param value The remote broker authentication methods. NOTE - Enum only one method is allowed to be passed.
     */
    @JvmName("mgwfxwkhnahlwafa")
    public suspend
    fun authentication(`value`: Output<MqttBridgeRemoteBrokerAuthenticationMethodsArgs>) {
        this.authentication = value
    }

    /**
     * @param value The endpoint of remote broker to connect to.
     */
    @JvmName("vuwjomlfujlsfltw")
    public suspend fun endpoint(`value`: Output<String>) {
        this.endpoint = value
    }

    /**
     * @param value Protocol for remote connection.
     */
    @JvmName("uvtkkjvxkniuwsqn")
    public suspend fun protocol(`value`: Output<Either<String, MqttBridgeRemoteBrokerProtocol>>) {
        this.protocol = value
    }

    /**
     * @param value TLS details for Remote broker Connection.
     */
    @JvmName("cflyxnguhnuysmwm")
    public suspend fun tls(`value`: Output<MqttBridgeRemoteBrokerConnectionTlsArgs>) {
        this.tls = value
    }

    /**
     * @param value The remote broker authentication methods. NOTE - Enum only one method is allowed to be passed.
     */
    @JvmName("ibkwwdjvnxfehlfm")
    public suspend fun authentication(`value`: MqttBridgeRemoteBrokerAuthenticationMethodsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param argument The remote broker authentication methods. NOTE - Enum only one method is allowed to be passed.
     */
    @JvmName("osuymaccrmwtxhkj")
    public suspend
    fun authentication(argument: suspend MqttBridgeRemoteBrokerAuthenticationMethodsArgsBuilder.() -> Unit) {
        val toBeMapped = MqttBridgeRemoteBrokerAuthenticationMethodsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.authentication = mapped
    }

    /**
     * @param value The endpoint of remote broker to connect to.
     */
    @JvmName("vbilnlbhcjceulom")
    public suspend fun endpoint(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value Protocol for remote connection.
     */
    @JvmName("llvbruuqavhfgsqe")
    public suspend fun protocol(`value`: Either<String, MqttBridgeRemoteBrokerProtocol>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value Protocol for remote connection.
     */
    @JvmName("kxxwyysvdrakxkad")
    public fun protocol(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MqttBridgeRemoteBrokerProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value Protocol for remote connection.
     */
    @JvmName("rwpletbslwuvgjef")
    public fun protocol(`value`: MqttBridgeRemoteBrokerProtocol) {
        val toBeMapped = Either.ofRight<String, MqttBridgeRemoteBrokerProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value TLS details for Remote broker Connection.
     */
    @JvmName("onwuunvwtileifvg")
    public suspend fun tls(`value`: MqttBridgeRemoteBrokerConnectionTlsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tls = mapped
    }

    /**
     * @param argument TLS details for Remote broker Connection.
     */
    @JvmName("tjdfylgiaquaepxr")
    public suspend
    fun tls(argument: suspend MqttBridgeRemoteBrokerConnectionTlsArgsBuilder.() -> Unit) {
        val toBeMapped = MqttBridgeRemoteBrokerConnectionTlsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.tls = mapped
    }

    internal fun build(): MqttBridgeRemoteBrokerConnectionSpecArgs =
        MqttBridgeRemoteBrokerConnectionSpecArgs(
            authentication = authentication ?: throw PulumiNullFieldException("authentication"),
            endpoint = endpoint ?: throw PulumiNullFieldException("endpoint"),
            protocol = protocol,
            tls = tls ?: throw PulumiNullFieldException("tls"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/MqttBridgeRemoteBrokerConnectionSpecArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.MqttBridgeRemoteBrokerConnectionSpecArgs.builder
import com.pulumi.azurenative.iotoperationsmq.kotlin.enums.MqttBridgeRemoteBrokerProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * MqttBridge RemoteBrokerConnectionSpec details
 * @property authentication The remote broker authentication methods. NOTE - Enum only one method is allowed to be passed.
 * @property endpoint The endpoint of remote broker to connect to.
 * @property protocol Protocol for remote connection.
 * @property tls TLS details for Remote broker Connection.
 */
public data class MqttBridgeRemoteBrokerConnectionSpecArgs(
    public val authentication: Output<MqttBridgeRemoteBrokerAuthenticationMethodsArgs>,
    public val endpoint: Output<String>,
    public val protocol: Output<Either<String, MqttBridgeRemoteBrokerProtocol>>? = null,
    public val tls: Output<MqttBridgeRemoteBrokerConnectionTlsArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.MqttBridgeRemoteBrokerConnectionSpecArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsmq.inputs.MqttBridgeRemoteBrokerConnectionSpecArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.MqttBridgeRemoteBrokerConnectionSpecArgs.builder()
            .authentication(authentication.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .endpoint(endpoint.applyValue({ args0 -> args0 }))
            .protocol(
                protocol?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .tls(tls.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [MqttBridgeRemoteBrokerConnectionSpecArgs].
 */
@PulumiTagMarker
public class MqttBridgeRemoteBrokerConnectionSpecArgsBuilder internal constructor() {
    private var authentication: Output<MqttBridgeRemoteBrokerAuthenticationMethodsArgs>? = null

    private var endpoint: Output<String>? = null

    private var protocol: Output<Either<String, MqttBridgeRemoteBrokerProtocol>>? = null

    private var tls: Output<MqttBridgeRemoteBrokerConnectionTlsArgs>? = null

    /**
     * @param value The remote broker authentication methods. NOTE - Enum only one method is allowed to be passed.
     */
    @JvmName("sgwympopjacwdnpy")
    public suspend
    fun authentication(`value`: Output<MqttBridgeRemoteBrokerAuthenticationMethodsArgs>) {
        this.authentication = value
    }

    /**
     * @param value The endpoint of remote broker to connect to.
     */
    @JvmName("lomnqxsxxhbeuhvb")
    public suspend fun endpoint(`value`: Output<String>) {
        this.endpoint = value
    }

    /**
     * @param value Protocol for remote connection.
     */
    @JvmName("dkyderoxrqlrlycm")
    public suspend fun protocol(`value`: Output<Either<String, MqttBridgeRemoteBrokerProtocol>>) {
        this.protocol = value
    }

    /**
     * @param value TLS details for Remote broker Connection.
     */
    @JvmName("iiqfoeitnkfdfgoo")
    public suspend fun tls(`value`: Output<MqttBridgeRemoteBrokerConnectionTlsArgs>) {
        this.tls = value
    }

    /**
     * @param value The remote broker authentication methods. NOTE - Enum only one method is allowed to be passed.
     */
    @JvmName("whyansrjmhjsdldy")
    public suspend fun authentication(`value`: MqttBridgeRemoteBrokerAuthenticationMethodsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param argument The remote broker authentication methods. NOTE - Enum only one method is allowed to be passed.
     */
    @JvmName("jfofxavodenkgylo")
    public suspend
    fun authentication(argument: suspend MqttBridgeRemoteBrokerAuthenticationMethodsArgsBuilder.() -> Unit) {
        val toBeMapped = MqttBridgeRemoteBrokerAuthenticationMethodsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.authentication = mapped
    }

    /**
     * @param value The endpoint of remote broker to connect to.
     */
    @JvmName("owqxsrxyrhccjcxc")
    public suspend fun endpoint(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value Protocol for remote connection.
     */
    @JvmName("axrtyeuxqtqokdmu")
    public suspend fun protocol(`value`: Either<String, MqttBridgeRemoteBrokerProtocol>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value Protocol for remote connection.
     */
    @JvmName("grjsflcunjtgfjmy")
    public fun protocol(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MqttBridgeRemoteBrokerProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value Protocol for remote connection.
     */
    @JvmName("nhyhwckguhuklxnw")
    public fun protocol(`value`: MqttBridgeRemoteBrokerProtocol) {
        val toBeMapped = Either.ofRight<String, MqttBridgeRemoteBrokerProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value TLS details for Remote broker Connection.
     */
    @JvmName("tbrtclokrpwfpelj")
    public suspend fun tls(`value`: MqttBridgeRemoteBrokerConnectionTlsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tls = mapped
    }

    /**
     * @param argument TLS details for Remote broker Connection.
     */
    @JvmName("rtjhparqjvfvirsu")
    public suspend
    fun tls(argument: suspend MqttBridgeRemoteBrokerConnectionTlsArgsBuilder.() -> Unit) {
        val toBeMapped = MqttBridgeRemoteBrokerConnectionTlsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.tls = mapped
    }

    internal fun build(): MqttBridgeRemoteBrokerConnectionSpecArgs =
        MqttBridgeRemoteBrokerConnectionSpecArgs(
            authentication = authentication ?: throw PulumiNullFieldException("authentication"),
            endpoint = endpoint ?: throw PulumiNullFieldException("endpoint"),
            protocol = protocol,
            tls = tls ?: throw PulumiNullFieldException("tls"),
        )
}
